==> developer-center-api-3.5.52-sources.jar: cn/com/duiba/developer/center/api/domain/paramquery/AppExtraParams.java <==
package cn.com.duiba.developer.center.api.domain.paramquery;

import java.io.Serializable;

/**
 * app扩展字段表单提交
 */
public class AppExtraParams implements Serializable {
	private static final long serialVersionUID = -8417873838307367386L;

	/**
	 * 功能开关
	 */
	public static final String SWITCH_OPEN = "on";

	private Long appId;
	private String entranceDesc;
	private String callLoginProgram;
	private String appType;
	private String useloginCode;
	private String freeItemVip;
	private String exchangeCreditsType;
	private String shareDesc;
	private String shareProgram;
	private String shareProgramType;
	private String noAbutmentType;
	private String canCustomSign;
	private String navProgramSwitch;
	private String navProgram;
	private String openCrecordKeFu;
	private String openFlowRuleRecordVisible;
	private String turnLuck;
	private String secKillValidation;
	private String exchangeValidation;
	private String forbidApp;//禁用app,兑吧全平台针对该app的访问都返回一个系统暂不可用的页面
	private String openRecommend;//App全局推荐状态
	private String flowViewTime;
	private String addVisterTime;//是否 开启 增加活动抽奖次数
	private String virturalOrderRetry; //虚拟商品是否开启
	private String accountSystem; //是否开启账号体系
	/**
	 * 是否可变现 开关  on为开{@link AppExtraParams.SWITCH_OPEN}
	 * */
	private String realizable;

	/**
	 * 开启兑换项线上剩余库存
	 */
	private String itemShowRemainStock;

	//是否测试应用
	private String trialVersion;

	/**
	 * dcustom 扩展参数
	 */
	private String dcustomExtra;

	public String getDcustomExtra() {
		return dcustomExtra;
	}

	public void setDcustomExtra(String dcustomExtra) {
		this.dcustomExtra = dcustomExtra;
	}

	public String getSecKillValidation() {
		return secKillValidation;
	}

	public void setSecKillValidation(String secKillValidation) {
		this.secKillValidation = secKillValidation;
	}

	public String getExchangeValidation() {
		return exchangeValidation;
	}

	public void setExchangeValidation(String exchangeValidation) {
		this.exchangeValidation = exchangeValidation;
	}

	public String getTurnLuck() {
		return turnLuck;
	}

	public void setTurnLuck(String turnLuck) {
		this.turnLuck = turnLuck;
	}

	public String getCanCustomSign() {
		return canCustomSign;
	}

	public void setCanCustomSign(String canCustomSign) {
		this.canCustomSign = canCustomSign;
	}

	public Long getAppId() {
		return appId;
	}
	public void setAppId(Long appId) {
		this.appId = appId;
	}
	public String getEntranceDesc() {
		return entranceDesc;
	}
	public void setEntranceDesc(String entranceDesc) {
		this.entranceDesc = entranceDesc;
	}
	public String getCallLoginProgram() {
		return callLoginProgram;
	}
	public void setCallLoginProgram(String callLoginProgram) {
		this.callLoginProgram = callLoginProgram;
	}
	public String getAppType() {
		return appType;
	}
	public void setAppType(String appType) {
		this.appType = appType;
	}
	public String getUseloginCode() {
		return useloginCode;
	}
	public void setUseloginCode(String useloginCode) {
		this.useloginCode = useloginCode;
	}
	public String getFreeItemVip() {
		return freeItemVip;
	}
	public void setFreeItemVip(String freeItemVip) {
		this.freeItemVip = freeItemVip;
	}
	public String getExchangeCreditsType() {
		return exchangeCreditsType;
	}
	public void setExchangeCreditsType(String exchangeCreditsType) {
		this.exchangeCreditsType = exchangeCreditsType;
	}
	public String getShareDesc() {
		return shareDesc;
	}
	public void setShareDesc(String shareDesc) {
		this.shareDesc = shareDesc;
	}
	public String getShareProgram() {
		return shareProgram;
	}
	public void setShareProgram(String shareProgram) {
		this.shareProgram = shareProgram;
	}
	public String getShareProgramType() {
		return shareProgramType;
	}
	public void setShareProgramType(String shareProgramType) {
		this.shareProgramType = shareProgramType;
	}
	public String getNoAbutmentType() {
		return noAbutmentType;
	}
	public void setNoAbutmentType(String noAbutmentType) {
		this.noAbutmentType = noAbutmentType;
	}

	public String getNavProgramSwitch() {
		return navProgramSwitch;
	}

	public void setNavProgramSwitch(String navProgramSwitch) {
		this.navProgramSwitch = navProgramSwitch;
	}

	public String getNavProgram() {
		return navProgram;
	}

	public void setNavProgram(String navProgram) {
		this.navProgram = navProgram;
	}

	public String getOpenCrecordKeFu() {
		return openCrecordKeFu;
	}

	public void setOpenCrecordKeFu(String openCrecordKeFu) {
		this.openCrecordKeFu = openCrecordKeFu;
	}

	public String getOpenFlowRuleRecordVisible() {
		return openFlowRuleRecordVisible;
	}

	public void setOpenFlowRuleRecordVisible(String openFlowRuleRecordVisible) {
		this.openFlowRuleRecordVisible = openFlowRuleRecordVisible;
	}

	public String getForbidApp() {
		return forbidApp;
	}

	public void setForbidApp(String forbidApp) {
		this.forbidApp = forbidApp;
	}

	public String getOpenRecommend() {
		return openRecommend;
	}

	public void setOpenRecommend(String openRecommend) {
		this.openRecommend = openRecommend;
	}

	public String getItemShowRemainStock() {
		return itemShowRemainStock;
	}

	public void setItemShowRemainStock(String itemShowRemainStock) {
		this.itemShowRemainStock = itemShowRemainStock;
	}

	public String getFlowViewTime() {
		return flowViewTime;
	}

	public void setFlowViewTime(String flowViewTime) {
		this.flowViewTime = flowViewTime;
	}

	public String getAddVisterTime() {
		return addVisterTime;
	}

	public void setAddVisterTime(String addVisterTime) {
		this.addVisterTime = addVisterTime;
	}

	public String getVirturalOrderRetry() {
		return virturalOrderRetry;
	}

	public void setVirturalOrderRetry(String virturalOrderRetry) {
		this.virturalOrderRetry = virturalOrderRetry;
	}

	public String getAccountSystem() {
		return accountSystem;
	}

	public void setAccountSystem(String accountSystem) {
		this.accountSystem = accountSystem;
	}

	public String getRealizable() {
		return realizable;
	}

	public void setRealizable(String realizable) {
		this.realizable = realizable;
	}

	public String getTrialVersion() {
		return trialVersion;
	}

	public void setTrialVersion(String trialVersion) {
		this.trialVersion = trialVersion;
	}
}

==> developer-center-api-3.5.60-sources.jar: cn/com/duiba/developer/center/api/domain/paramquery/AppExtraParams.java <==
package cn.com.duiba.developer.center.api.domain.paramquery;

import java.io.Serializable;

/**
 * app扩展字段表单提交
 */
public class AppExtraParams implements Serializable {
	private static final long serialVersionUID = -8417873838307367386L;

	/**
	 * 功能开关
	 */
	public static final String SWITCH_OPEN = "on";

	private Long appId;
	private String entranceDesc;
	private String callLoginProgram;
	private String appType;
	private String useloginCode;
	private String freeItemVip;
	private String exchangeCreditsType;
	private String shareDesc;
	private String shareProgram;
	private String shareProgramType;
	private String noAbutmentType;
	private String canCustomSign;
	private String navProgramSwitch;
	private String navProgram;
	private String openCrecordKeFu;
	private String openFlowRuleRecordVisible;
	private String turnLuck;
	private String secKillValidation;
	private String exchangeValidation;
	private String forbidApp;//禁用app,兑吧全平台针对该app的访问都返回一个系统暂不可用的页面
	private String openRecommend;//App全局推荐状态
	private String flowViewTime;
	private String addVisterTime;//是否 开启 增加活动抽奖次数
	private String virturalOrderRetry; //虚拟商品是否开启
	private String accountSystem; //是否开启账号体系
	/**
	 * 是否可变现 开关  on为开{@link AppExtraParams.SWITCH_OPEN}
	 * */
	private String realizable;

	/**
	 * 开启兑换项线上剩余库存
	 */
	private String itemShowRemainStock;


	/**
	 * 是否展示线上库存
	 */
	private String showExpressInfo;

	//是否测试应用
	private String trialVersion;

	/**
	 * dcustom 扩展参数
	 */
	private String dcustomExtra;

	public String getShowExpressInfo() {
		return showExpressInfo;
	}

	public void setShowExpressInfo(String showExpressInfo) {
		this.showExpressInfo = showExpressInfo;
	}

	public String getDcustomExtra() {
		return dcustomExtra;
	}

	public void setDcustomExtra(String dcustomExtra) {
		this.dcustomExtra = dcustomExtra;
	}

	public String getSecKillValidation() {
		return secKillValidation;
	}

	public void setSecKillValidation(String secKillValidation) {
		this.secKillValidation = secKillValidation;
	}

	public String getExchangeValidation() {
		return exchangeValidation;
	}

	public void setExchangeValidation(String exchangeValidation) {
		this.exchangeValidation = exchangeValidation;
	}

	public String getTurnLuck() {
		return turnLuck;
	}

	public void setTurnLuck(String turnLuck) {
		this.turnLuck = turnLuck;
	}

	public String getCanCustomSign() {
		return canCustomSign;
	}

	public void setCanCustomSign(String canCustomSign) {
		this.canCustomSign = canCustomSign;
	}

	public Long getAppId() {
		return appId;
	}
	public void setAppId(Long appId) {
		this.appId = appId;
	}
	public String getEntranceDesc() {
		return entranceDesc;
	}
	public void setEntranceDesc(String entranceDesc) {
		this.entranceDesc = entranceDesc;
	}
	public String getCallLoginProgram() {
		return callLoginProgram;
	}
	public void setCallLoginProgram(String callLoginProgram) {
		this.callLoginProgram = callLoginProgram;
	}
	public String getAppType() {
		return appType;
	}
	public void setAppType(String appType) {
		this.appType = appType;
	}
	public String getUseloginCode() {
		return useloginCode;
	}
	public void setUseloginCode(String useloginCode) {
		this.useloginCode = useloginCode;
	}
	public String getFreeItemVip() {
		return freeItemVip;
	}
	public void setFreeItemVip(String freeItemVip) {
		this.freeItemVip = freeItemVip;
	}
	public String getExchangeCreditsType() {
		return exchangeCreditsType;
	}
	public void setExchangeCreditsType(String exchangeCreditsType) {
		this.exchangeCreditsType = exchangeCreditsType;
	}
	public String getShareDesc() {
		return shareDesc;
	}
	public void setShareDesc(String shareDesc) {
		this.shareDesc = shareDesc;
	}
	public String getShareProgram() {
		return shareProgram;
	}
	public void setShareProgram(String shareProgram) {
		this.shareProgram = shareProgram;
	}
	public String getShareProgramType() {
		return shareProgramType;
	}
	public void setShareProgramType(String shareProgramType) {
		this.shareProgramType = shareProgramType;
	}
	public String getNoAbutmentType() {
		return noAbutmentType;
	}
	public void setNoAbutmentType(String noAbutmentType) {
		this.noAbutmentType = noAbutmentType;
	}

	public String getNavProgramSwitch() {
		return navProgramSwitch;
	}

	public void setNavProgramSwitch(String navProgramSwitch) {
		this.navProgramSwitch = navProgramSwitch;
	}

	public String getNavProgram() {
		return navProgram;
	}

	public void setNavProgram(String navProgram) {
		this.navProgram = navProgram;
	}

	public String getOpenCrecordKeFu() {
		return openCrecordKeFu;
	}

	public void setOpenCrecordKeFu(String openCrecordKeFu) {
		this.openCrecordKeFu = openCrecordKeFu;
	}

	public String getOpenFlowRuleRecordVisible() {
		return openFlowRuleRecordVisible;
	}

	public void setOpenFlowRuleRecordVisible(String openFlowRuleRecordVisible) {
		this.openFlowRuleRecordVisible = openFlowRuleRecordVisible;
	}

	public String getForbidApp() {
		return forbidApp;
	}

	public void setForbidApp(String forbidApp) {
		this.forbidApp = forbidApp;
	}

	public String getOpenRecommend() {
		return openRecommend;
	}

	public void setOpenRecommend(String openRecommend) {
		this.openRecommend = openRecommend;
	}

	public String getItemShowRemainStock() {
		return itemShowRemainStock;
	}

	public void setItemShowRemainStock(String itemShowRemainStock) {
		this.itemShowRemainStock = itemShowRemainStock;
	}

	public String getFlowViewTime() {
		return flowViewTime;
	}

	public void setFlowViewTime(String flowViewTime) {
		this.flowViewTime = flowViewTime;
	}

	public String getAddVisterTime() {
		return addVisterTime;
	}

	public void setAddVisterTime(String addVisterTime) {
		this.addVisterTime = addVisterTime;
	}

	public String getVirturalOrderRetry() {
		return virturalOrderRetry;
	}

	public void setVirturalOrderRetry(String virturalOrderRetry) {
		this.virturalOrderRetry = virturalOrderRetry;
	}

	public String getAccountSystem() {
		return accountSystem;
	}

	public void setAccountSystem(String accountSystem) {
		this.accountSystem = accountSystem;
	}

	public String getRealizable() {
		return realizable;
	}

	public void setRealizable(String realizable) {
		this.realizable = realizable;
	}

	public String getTrialVersion() {
		return trialVersion;
	}

	public void setTrialVersion(String trialVersion) {
		this.trialVersion = trialVersion;
	}
}
